HistoryLiveMap<K, V> class

Inheritance
Mixed-in types

Constructors

HistoryLiveMap({Map<K, V>? source, StringEncode<Map<K, V>>? encode, StringDecode<Map<K, V>>? decode})

Properties

active bool
no setterinherited
canRedo LiveData<bool>
finalinherited
canUndo LiveData<bool>
finalinherited
capacity int
getter/setter pairinherited
decode StringDecode<Map<K, V>>?
final
encode StringEncode<Map<K, V>>?
final
entries Iterable<MapEntry<K, V>>
The map entries of this Map.
no setterinherited
equality → Equality<Map<K, V>>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
history List<String>
finalinherited
index int
getter/setter pairinherited
initialized bool
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys Iterable<K>
The keys of this Map.
no setterinherited
length int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueEquality → Equality<V?>
finalinherited
values Iterable<V>
The values of this Map.
no setterinherited
version int
no setterinherited

Methods

addAll(Map<K, V> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<K, V>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
apply(bool update(Map<K, V> data)) bool
inherited
cast<K2, V2>() Map<K2, V2>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) bool
Whether this map contains the given key.
inherited
containsValue(Object? value) bool
Whether this map contains the given value.
inherited
forEach(void f(K, V)) → void
Applies action to each key/value pair of the map.
inherited
historyClear() → void
inherited
historyRedo() → void
inherited
historyReplace(Map<K, V> data, {int? index}) → void
inherited
historyUndo() → void
inherited
invalidate() → void
inherited
map<K2, V2>(MapEntry<K2, V2> transform(K, V)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observeForever(Observer<Map<K, V>> onChanged, {Dispatcher? dispatcher}) Disposable
inherited
onActive() → void
inherited
onInactive() → void
inherited
postSetTo(FutureOr<Map<K, V>> value) → void
inherited
putIfAbsent(K key, V ifAbsent()) → V
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → V?
Removes key and its associated value, if present, from the map.
inherited
removeObserver(Observer<Map<K, V>> onChanged) → void
inherited
removeWhere(bool test(K, V)) → void
Removes all entries of this map that satisfy the given test.
inherited
restoreState(int index) → void
inherited
saveState() → void
inherited
setIndexInternal(int value) → void
inherited
setTo(Map<K, V> value) → void
inherited
toString() String
A string representation of this object.
inherited
update(K key, V update(V), {V ifAbsent()?}) → V
Updates the value for the provided key.
inherited
updateAll(V update(K, V)) → void
Updates all values.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?
The value for the given key, or null if key is not in the map.
inherited
operator []=(K key, V value) → void
Associates the key with the given value.
inherited