MutableLiveData<T> class

Inheritance
Implementers
Available extensions

Constructors

MutableLiveData({T? value, Equality<T>? equality})
MutableLiveData.late({Equality<T>? equality})

Properties

active bool
no setterinherited
equality → Equality<T>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialized bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pairinherited-getter
valueOrNull → T?
no setterinherited
version int
no setterinherited

Methods

invalidate() → void
inherited
linkStream<X>(Stream<X> stream, [FutureOr<T> transform(X)?]) StreamSubscription<X>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observe(ObserverMixin context, Observer<T> onChanged, {Dispatcher? dispatcher}) → void

Available on ObservableData<T>, provided by the ObservableDataExt extension

observeForever(Observer<T> onChanged, {Dispatcher? dispatcher}) Disposable
inherited
onActive() → void
inherited
onInactive() → void
inherited
postValue(FutureOr<T> value) → void
removeObserver(Observer<T> onChanged) → void
inherited
toggle() → void

Available on MutableLiveData<bool>, provided by the ToggleLiveDataExt extension

toString() String
A string representation of this object.
inherited
transform<Y>(FutureOr<Y> transform(T), {bool reactive = false}) MediatorLiveData<Y>

Available on ObservableData<T>, provided by the ObservableDataExt extension

whenValue({bool accept(T)?, Dispatcher? dispatcher, Duration? timeLimit, FutureOr<T> onTimeout()?, Future<T>? cancel}) Future<T>

Available on ObservableData<T>, provided by the ObservableDataExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited